@@ -14,6 +14,10 @@ logger = logging.getLogger(__name__)
 
 def extension(app):
     logger.info("Loading Redash Extension for Dockerflow")
-    dockerflow = Dockerflow(app, db=db, migrate=migrate, redis=redis_connection)
-    logger.info("Loaded Redash Extension for Dockerflow")
-    return dockerflow
+    try:
+        dockerflow = Dockerflow(app, db=db, migrate=migrate, redis=redis_connection)
+    except AssertionError:
+        pass
+    else:
+        logger.info("Loaded Redash Extension for Dockerflow")
+        return dockerflow
